# generated by datamodel-codegen:
#   filename:  sensors.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class Sensors(BaseModel):
    """
    Sensors
    """

    class Config:
        extra = Extra.allow

    id: str | None = Field(None, description="Event ID")
    last_updated: dict[str, float] | None = Field(None, description="Last updated")



# generated by datamodel-codegen:
#   filename:  disk.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    devices: float
    io_counters_read_count: float | None = None
    io_counters_write_count: float | None = None
    io_counters_read_bytes: float | None = None
    io_counters_write_bytes: float | None = None
    io_counters_read_time: float | None = None
    io_counters_write_time: float | None = None
    partitions: float


class Disk(BaseModel):
    """
    Disk
    """

    class Config:
        extra = Extra.allow

    id: str | None = Field(None, description="Event ID")
    devices: list
    io_counters_read_count: int | None = None
    io_counters_write_count: int | None = None
    io_counters_read_bytes: int | None = None
    io_counters_write_bytes: int | None = None
    io_counters_read_time: int | None = None
    io_counters_write_time: int | None = None
    partitions: list
    last_updated: LastUpdated | None = Field(None, description="Last updated")



# generated by datamodel-codegen:
#   filename:  memory.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    swap_total: float | None = None
    swap_used: float | None = None
    swap_free: float | None = None
    swap_percent: float | None = None
    swap_sin: float | None = None
    swap_sout: float | None = None
    virtual_total: float | None = None
    virtual_available: float | None = None
    virtual_percent: float | None = None
    virtual_used: float | None = None
    virtual_free: float | None = None


class Memory(BaseModel):
    """
    Memory
    """

    class Config:
        extra = Extra.allow

    id: str | None = Field(None, description="Event ID")
    swap_total: int | None = None
    swap_used: int | None = None
    swap_free: float | None = None
    swap_percent: float | None = None
    swap_sin: int | None = None
    swap_sout: int | None = None
    virtual_total: int | None = None
    virtual_available: int | None = None
    virtual_percent: float | None = None
    virtual_used: int | None = None
    virtual_free: int | None = None
    last_updated: LastUpdated | None = Field(None, description="Last updated")



# generated by datamodel-codegen:
#   filename:  notification.json

from __future__ import annotations

from typing import Any

from pydantic import BaseModel, confloat


class Action(BaseModel):
    """
    Notification Action
    """

    command: str
    data: dict[str, Any] | None = None
    label: str


class Audio(BaseModel):
    source: str
    volume: confloat(ge=0.0, le=100.0) | None = None


class Notification(BaseModel):
    """
    Notification
    """

    title: str
    message: str | None = None
    icon: str | None = None
    image: str | None = None
    actions: list[Action] | None = None
    timeout: float | None = None
    audio: Audio | None = None



# generated by datamodel-codegen:
#   filename:  processes.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class Process(BaseModel):
    """
    Process
    """

    class Config:
        extra = Extra.allow

    id: float = Field(..., description="ID")
    name: str = Field(..., description="Name")
    cpu_usage: float | None = Field(None, description="CPU usage percentage")
    created: float | None = Field(None, description="Created time (epoch)")
    memory_usage: float | None = Field(None, description="Memory usage percentage")
    path: str | None = Field(None, description="Path")
    status: str | None = Field(None, description="Status")
    username: str | None = Field(None, description="Username")
    working_directory: str | None = Field(None, description="Working directory")


class LastUpdated(BaseModel):
    """
    Last updated
    """

    count: float
    processes: float


class Processes(BaseModel):
    """
    Processes
    """

    id: str | None = Field(None, description="Event ID")
    count: float
    processes: list[Process] = Field(..., description="Processes")
    last_updated: LastUpdated | None = Field(None, description="Last updated")



# generated by datamodel-codegen:
#   filename:  network.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    io_counters_bytes_sent: float | None = None
    io_counters_bytes_recv: float | None = None
    io_counters_packets_sent: float | None = None
    io_counters_packets_recv: float | None = None
    io_counters_errin: float | None = None
    io_counters_errout: float | None = None
    io_counters_dropin: float | None = None
    io_counters_dropout: float | None = None


class Network(BaseModel):
    """
    Network
    """

    class Config:
        extra = Extra.allow

    id: str | None = Field(None, description="Event ID")
    io_counters_bytes_sent: int | None = None
    io_counters_bytes_recv: int | None = None
    io_counters_packets_sent: int | None = None
    io_counters_packets_recv: int | None = None
    io_counters_errin: int | None = None
    io_counters_errout: int | None = None
    io_counters_dropin: int | None = None
    io_counters_dropout: int | None = None
    last_updated: LastUpdated | None = Field(None, description="Last updated")



# generated by datamodel-codegen:
#   filename:  media_play.json

from __future__ import annotations

from pydantic import BaseModel


class MediaPlay(BaseModel):
    """
    Media Play
    """

    album: str | None = None
    artist: str | None = None
    autoplay: bool | None = False
    cover: str | None = None
    title: str | None = None
    url: str
    volume: float | None = 40



# generated by datamodel-codegen:
#   filename:  cpu.json

from __future__ import annotations

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    count: float | None = None
    frequency_current: float | None = None
    frequency_min: float | None = None
    frequency_max: float | None = None
    load_average: float | None = None
    power_package: float | None = None
    stats_ctx_switches: float | None = None
    stats_interrupts: float | None = None
    stats_soft_interrupts: float | None = None
    stats_syscalls: float | None = None
    temperature: float | None = None
    times_user: float | None = None
    times_system: float | None = None
    times_idle: float | None = None
    times_interrupt: float | None = None
    times_dpc: float | None = None
    times_percent_user: float | None = None
    times_percent_system: float | None = None
    times_percent_idle: float | None = None
    times_percent_interrupt: float | None = None
    times_percent_dpc: float | None = None
    usage: float | None = None
    voltage: float | None = None


class Cpu(BaseModel):
    """
    CPU
    """

    class Config:
        extra = Extra.allow

    id: str | None = Field(None, description="Event ID")
    count: int | None = None
    frequency_current: float | None = None
    frequency_min: float | None = None
    frequency_max: float | None = None
    load_average: float | None = None
    power_package: float | None = None
    stats_ctx_switches: int | None = None
    stats_interrupts: int | None = None
    stats_soft_interrupts: int | None = None
    stats_syscalls: int | None = None
    temperature: float | None = None
    times_user: float | None = None
    times_system: float | None = None
    times_idle: float | None = None
    times_interrupt: float | None = None
    times_dpc: float | None = None
    times_percent_user: float | None = None
    times_percent_system: float | None = None
    times_percent_idle: float | None = None
    times_percent_interrupt: float | None = None
    times_percent_dpc: float | None = None
    usage: float | None = None
    voltage: float | None = None
    last_updated: LastUpdated | None = Field(None, description="Last updated")
